pub struct ModelPricing {
pub input_per_million: f64,
pub output_per_million: f64,
pub cache_read_per_million: Option<f64>,
pub cache_write_per_million: Option<f64>,
}Expand description
Provider/model prices sourced from models.dev, denominated in USD per million tokens.
Fields
input_per_million: f64output_per_million: f64cache_read_per_million: Option<f64>cache_write_per_million: Option<f64>Trait Implementations
Sourceimpl Clone for ModelPricing
impl Clone for ModelPricing
Sourcefn clone(&self) -> ModelPricing
fn clone(&self) -> ModelPricing
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ModelPricing
Sourceimpl Debug for ModelPricing
impl Debug for ModelPricing
Sourceimpl<'de> Deserialize<'de> for ModelPricing
impl<'de> Deserialize<'de> for ModelPricing
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelPricing
impl JsonSchema for ModelPricing
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModelPricing
impl PartialEq for ModelPricing
Sourceimpl Serialize for ModelPricing
impl Serialize for ModelPricing
impl StructuralPartialEq for ModelPricing