LlamaCpp LLM provider.
This provider accepts any model name at runtime (e.g. llamacpp:my-model).
No API key is required.
LlamaCpp LLM provider.
This provider accepts any model name at runtime (e.g. llamacpp:my-model).
No API key is required.