FakeLlmProvider

Struct FakeLlmProvider 

pub struct FakeLlmProvider { /* private fields */ }

Implementations

Source

impl FakeLlmProvider

pub fn new(responses: Vec<Vec<LlmResponse>>) -> Self

pub fn with_single_response(chunks: Vec<LlmResponse>) -> Self

pub fn from_results(responses: Vec<Vec<Result<LlmResponse, LlmError>>>) -> Self

pub fn with_display_name(self, name: &str) -> Self

pub fn with_context_window(self, window: Option<u32>) -> Self

pub fn captured_contexts(&self) -> Arc<Mutex<Vec<Context>>>

Returns a handle to the captured contexts that can be used to verify what contexts were passed to the LLM.