pub struct ModelIdentity {
pub provider: Option<String>,
pub model_id: Option<String>,
pub pricing: Option<ModelPricing>,
}Expand description
Provider, model id, and catalog pricing of the model serving a call. All
fields are None for dynamic or local models the catalog does not know.
Fields
provider: Option<String>model_id: Option<String>pricing: Option<ModelPricing>Implementations