pub struct SessionUsageEvent {
pub sequence: u64,
pub source: UsageSource,
pub purpose: LlmCallPurpose,
pub model: ModelIdentity,
pub tokens: TokenUsage,
pub estimated_cost: Option<UsageCost>,
pub totals: SessionUsageTotals,
}Expand description
One provider usage sample, its estimated cost, and the totals after it.
Fields
sequence: u64source: UsageSourcepurpose: LlmCallPurposemodel: ModelIdentitytokens: TokenUsageestimated_cost: Option<UsageCost>totals: SessionUsageTotalsTrait Implementations
Sourceimpl Clone for SessionUsageEvent
impl Clone for SessionUsageEvent
Sourcefn clone(&self) -> SessionUsageEvent
fn clone(&self) -> SessionUsageEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionUsageEvent
impl Debug for SessionUsageEvent
Sourceimpl<'de> Deserialize<'de> for SessionUsageEvent
impl<'de> Deserialize<'de> for SessionUsageEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionUsageEvent
impl JsonSchema for SessionUsageEvent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionUsageEvent
impl PartialEq for SessionUsageEvent
Sourceimpl Serialize for SessionUsageEvent
impl Serialize for SessionUsageEvent
impl StructuralPartialEq for SessionUsageEvent