pub struct UsageCost {
pub input_usd: Usd,
pub output_usd: Usd,
pub cache_read_usd: Usd,
pub cache_creation_usd: Usd,
pub total_usd: Usd,
}Expand description
Estimated USD cost of one call, split by token pool.
Fields
input_usd: Usdoutput_usd: Usdcache_read_usd: Usdcache_creation_usd: Usdtotal_usd: UsdTrait Implementations
impl Copy for UsageCost
Sourceimpl<'de> Deserialize<'de> for UsageCost
impl<'de> Deserialize<'de> for UsageCost
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageCost
impl JsonSchema for UsageCost
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for UsageCost