pub fn get_context_window(provider: &str, model_id: &str) -> Option<u32>
Look up context window for a known provider + model ID combo via the catalog.
Returns None if the model is not in the catalog.
None